pub struct Config {
pub mysql: MySqlConfig,
pub postgres: PgConfig,
pub sqlite: SqliteConfig,
pub external: ExternalDriverConfig,
}_unstable-docs only.Expand description
Configuration for specific database drivers (applies to macros and sqlx-cli only).
Note: Does Not Apply at Application Run-Time
As of writing, these configuration parameters do not have any bearing on the runtime configuration of SQLx database drivers.
Any parameters which overlap with runtime configuration
(e.g. drivers.sqlite.unsafe-load-extensions)
must be configured their normal ways at runtime (e.g. SqliteConnectOptions::extension()).
See the documentation of individual fields for details.
Fields
mysql: MySqlConfigConfiguration for the MySQL database driver.
See MySqlConfig for details.
postgres: PgConfigConfiguration for the Postgres database driver.
See PgConfig for details.
sqlite: SqliteConfigConfiguration for the SQLite database driver.
See SqliteConfig for details.
external: ExternalDriverConfigConfiguration for external database drivers.
See ExternalDriverConfig for details.