pub struct PreferredCrates {
pub date_time: DateTimeCrate,
pub numeric: NumericCrate,
}_unstable-docs only.Fields
date_time: DateTimeCrateSpecify the crate to use for mapping date/time types to Rust.
The default behavior is to use whatever crate is enabled,
chrono or time (the latter takes precedent).
Example: Always Use Chrono
Thanks to Cargoโs feature unification, a crate in the dependency graph may enable
the time feature of SQLx which will force it on for all crates using SQLx,
which will result in problems if your crate wants to use types from chrono.
You can use the type override syntax (see sqlx::query! for details),
or you can force an override globally by setting this option.
sqlx.toml
[macros.preferred-crates]
date-time = "chrono"numeric: NumericCrateSpecify the crate to use for mapping NUMERIC types to Rust.
The default behavior is to use whatever crate is enabled,
bigdecimal or rust_decimal (the latter takes precedent).
Example: Always Use bigdecimal
Thanks to Cargoโs feature unification, a crate in the dependency graph may enable
the rust_decimal feature of SQLx which will force it on for all crates using SQLx,
which will result in problems if your crate wants to use types from bigdecimal.
You can use the type override syntax (see sqlx::query! for details),
or you can force an override globally by setting this option.
sqlx.toml
[macros.preferred-crates]
numeric = "bigdecimal"Trait Implementations
Sourceimpl Debug for PreferredCrates
impl Debug for PreferredCrates
Sourceimpl Default for PreferredCrates
impl Default for PreferredCrates
Sourcefn default() -> PreferredCrates
fn default() -> PreferredCrates