pub enum DefaultMigrationType {
Inferred,
Simple,
Reversible,
}Available on crate feature
_unstable-docs only.Expand description
The default type of migration that sqlx migrate add should create by default.
Variants
Inferred
Create the same migration type as that of the latest existing migration,
or Simple otherwise.
Simple
Create non-reversible migrations (<VERSION>_<DESCRIPTION>.sql) by default.
Reversible
Create reversible migrations (<VERSION>_<DESCRIPTION>.up.sql and [...].down.sql) by default.