pub enum DefaultVersioning {
Inferred,
Timestamp,
Sequential,
}Available on crate feature
_unstable-docs only.Expand description
The default scheme that sqlx migrate add should use for version integers.
Variants
Inferred
Infer the versioning scheme from existing migrations:
- If the versions of the last two migrations differ by
1, inferSequential. - If only one migration exists and has version
1, inferSequential. - Otherwise, infer
Timestamp.
Timestamp
Use UTC timestamps for migration versions.
This is the recommended versioning format as itโs less likely to collide when multiple developers are creating migrations on different branches.
The exact timestamp format is unspecified.
Sequential
Use sequential integers for migration versions.