pub struct MigrationDefaults {
pub migration_type: DefaultMigrationType,
pub migration_versioning: DefaultVersioning,
}Available on crate feature
_unstable-docs only.Fields
migration_type: DefaultMigrationTypeSpecify the default type of migration that sqlx migrate add should create by default.
Example: Use Reversible Migrations by Default
sqlx.toml:
[migrate.defaults]
migration-type = "reversible"migration_versioning: DefaultVersioningSpecify the default scheme that sqlx migrate add should use for version integers.
Example: Use Sequential Versioning by Default
sqlx.toml:
[migrate.defaults]
migration-versioning = "sequential"Trait Implementations
Sourceimpl Debug for MigrationDefaults
impl Debug for MigrationDefaults
Sourceimpl Default for MigrationDefaults
impl Default for MigrationDefaults
Sourcefn default() -> MigrationDefaults
fn default() -> MigrationDefaults
Returns the โdefault valueโ for a type. Read more