pub struct Config {
pub common: Config,
pub drivers: Config,
pub macros: Config,
pub migrate: Config,
}Available on crate feature
_unstable-docs only.Expand description
The parsed structure of a sqlx.toml file.
Fields
common: ConfigConfiguration shared by multiple components.
See common::Config for details.
drivers: ConfigConfiguration for database drivers.
See drivers::Config for details.
macros: ConfigConfiguration for the query!() family of macros.
See macros::Config for details.
migrate: ConfigConfiguration for migrations when executed using sqlx::migrate!() or through sqlx-cli.
See migrate::Config for details.
Implementations
Sourceimpl Config
Internal methods for loading a Config.
impl Config
Internal methods for loading a Config.
Sourcepub fn try_from_crate_or_default() -> Result<Config, ConfigError>
pub fn try_from_crate_or_default() -> Result<Config, ConfigError>
Read $CARGO_MANIFEST_DIR/sqlx.toml or return Config::default() if it does not exist.
Errors
- If
CARGO_MANIFEST_DIRis not set. - If the file exists but could not be read or parsed.
- If the file exists but the
sqlx-tomlfeature is disabled.
Sourcepub fn try_from_path_or_default(path: PathBuf) -> Result<Config, ConfigError>
pub fn try_from_path_or_default(path: PathBuf) -> Result<Config, ConfigError>
Attempt to read Config from the path given, or return Config::default() if it does not exist.
Errors
- If the file exists but could not be read or parsed.
- If the file exists but the
sqlx-tomlfeature is disabled.
Sourcepub fn try_from_path(path: PathBuf) -> Result<Config, ConfigError>
pub fn try_from_path(path: PathBuf) -> Result<Config, ConfigError>
Attempt to read Config from the path given.
Errors
- If the file does not exist.
- If the file exists but could not be read or parsed.
- If the file exists but the
sqlx-tomlfeature is disabled.