pub struct AnyStatement { /* private fields */ }Available on crate feature
any only.Trait Implementations
Sourceimpl Clone for AnyStatement
impl Clone for AnyStatement
Sourcefn clone(&self) -> AnyStatement
fn clone(&self) -> AnyStatement
Returns a duplicate of the value. Read more
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ColumnIndex<AnyStatement> for &str
impl ColumnIndex<AnyStatement> for &str
Sourcefn index(&self, statement: &AnyStatement) -> Result<usize, Error>
fn index(&self, statement: &AnyStatement) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.Sourceimpl ColumnIndex<AnyStatement> for usize
impl ColumnIndex<AnyStatement> for usize
Sourcefn index(&self, statement: &AnyStatement) -> Result<usize, Error>
fn index(&self, statement: &AnyStatement) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.Sourceimpl Statement for AnyStatement
impl Statement for AnyStatement
type Database = Any
Sourcefn parameters(&self) -> Option<Either<&[AnyTypeInfo], usize>>
fn parameters(&self) -> Option<Either<&[AnyTypeInfo], usize>>
Get the expected parameters for this statement. Read more
Sourcefn columns(&self) -> &[AnyColumn]
fn columns(&self) -> &[AnyColumn]
Get the columns expected to be returned by executing this statement.
fn query( &self, ) -> Query<'_, <AnyStatement as Statement>::Database, AnyArguments>
fn query_with<A>( &self, arguments: A, ) -> Query<'_, <AnyStatement as Statement>::Database, A>
fn query_as<O>( &self, ) -> QueryAs<'_, <AnyStatement as Statement>::Database, O, <<AnyStatement as Statement>::Database as Database>::Arguments>
fn query_as_with<'s, O, A>(
&'s self,
arguments: A,
) -> QueryAs<'s, <AnyStatement as Statement>::Database, O, A>where
O: for<'r> FromRow<'r, <<AnyStatement as Statement>::Database as Database>::Row>,
A: IntoArguments<<AnyStatement as Statement>::Database>,
fn query_scalar<O>( &self, ) -> QueryScalar<'_, <AnyStatement as Statement>::Database, O, <<AnyStatement as Statement>::Database as Database>::Arguments>
fn query_scalar_with<'s, O, A>(
&'s self,
arguments: A,
) -> QueryScalar<'s, <AnyStatement as Statement>::Database, O, A>where
(O,): for<'r> FromRow<'r, <<AnyStatement as Statement>::Database as Database>::Row>,
A: IntoArguments<<AnyStatement as Statement>::Database>,
Sourcefn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
Gets the column information at
index. Read moreSourcefn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
fn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
Gets the column information at
index or a ColumnIndexOutOfBounds error if out of bounds.Auto Trait Implementations
impl Freeze for AnyStatement
impl RefUnwindSafe for AnyStatement
impl Send for AnyStatement
impl Sync for AnyStatement
impl Unpin for AnyStatement
impl UnwindSafe for AnyStatement