pub struct AnyTransactionManager;Available on crate feature
any only.Trait Implementations
Sourceimpl TransactionManager for AnyTransactionManager
impl TransactionManager for AnyTransactionManager
type Database = Any
Sourcefn begin(
conn: &mut AnyConnection,
statement: Option<SqlStr>,
) -> impl Future<Output = Result<(), Error>> + Send
fn begin( conn: &mut AnyConnection, statement: Option<SqlStr>, ) -> impl Future<Output = Result<(), Error>> + Send
Begin a new transaction or establish a savepoint within the active transaction. Read more
Sourcefn commit(
conn: &mut AnyConnection,
) -> impl Future<Output = Result<(), Error>> + Send
fn commit( conn: &mut AnyConnection, ) -> impl Future<Output = Result<(), Error>> + Send
Commit the active transaction or release the most recent savepoint.
Sourcefn rollback(
conn: &mut AnyConnection,
) -> impl Future<Output = Result<(), Error>> + Send
fn rollback( conn: &mut AnyConnection, ) -> impl Future<Output = Result<(), Error>> + Send
Abort the active transaction or restore from the most recent savepoint.
Sourcefn start_rollback(conn: &mut AnyConnection)
fn start_rollback(conn: &mut AnyConnection)
Starts to abort the active transaction or restore from the most recent snapshot.
Sourcefn get_transaction_depth(
conn: &<<AnyTransactionManager as TransactionManager>::Database as Database>::Connection,
) -> usize
fn get_transaction_depth( conn: &<<AnyTransactionManager as TransactionManager>::Database as Database>::Connection, ) -> usize
Returns the current transaction depth. Read more