[−][src]Trait sqlx::cursor::HasCursor
Associate Database with a Cursor of a generic lifetime.
The upcoming Rust feature, Generic Associated Types, should obviate the need for this trait.
Associated Types
type Database: Database
type Cursor: Cursor<'c, 'q>
The concrete Cursor implementation for this database.