pub enum ColumnOrigin {
Table(TableColumn),
Expression,
Unknown,
}Expand description
The possible statuses for our knowledge of the origin of a Column.
Variants
Table(TableColumn)
The column is known to originate from a table.
Included is the table name and original column name.
Expression
The column originates from an expression, or else its origin could not be determined.
Unknown
The database driver does not know the column origin at this time.
This may happen if:
- The connection is in the middle of executing a query, and cannot query the catalog to fetch this information.
- The connection does not have access to the database catalog.
- The implementation of
Columndid not overrideColumn::origin().
Implementations
Sourceimpl ColumnOrigin
impl ColumnOrigin
Sourcepub fn table_column(&self) -> Option<&TableColumn>
pub fn table_column(&self) -> Option<&TableColumn>
Returns the true column origin, if known.