pub enum MigrationType {
Simple,
ReversibleUp,
ReversibleDown,
}Available on crate feature
migrate only.Expand description
Migration Type represents the type of migration
Variants
Simple
Simple migration are single file migrations with no up / down queries
ReversibleUp
ReversibleUp migrations represents the add or update part of a reversible migrations It is expected the every migration of this type will have a corresponding down file
ReversibleDown
ReversibleDown migrations represents the delete or downgrade part of a reversible migrations It is expected the every migration of this type will have a corresponding up file
Implementations
Sourceimpl MigrationType
impl MigrationType
pub fn from_filename(filename: &str) -> MigrationType
pub fn is_reversible(&self) -> bool
pub fn is_up_migration(&self) -> bool
pub fn is_down_migration(&self) -> bool
pub fn label(&self) -> &'static str
pub fn suffix(&self) -> &'static str
pub fn file_content(&self) -> &'static str
pub fn infer(migrator: &Migrator, reversible: bool) -> MigrationType
๐Deprecated:
unused