pub struct MySqlStatement { /* private fields */ }Available on crate feature
mysql only.Trait Implementations
Sourceimpl Clone for MySqlStatement
impl Clone for MySqlStatement
Sourcefn clone(&self) -> MySqlStatement
fn clone(&self) -> MySqlStatement
Returns a duplicate of the value. Read more
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ColumnIndex<MySqlStatement> for &str
impl ColumnIndex<MySqlStatement> for &str
Sourcefn index(&self, statement: &MySqlStatement) -> Result<usize, Error>
fn index(&self, statement: &MySqlStatement) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.Sourceimpl ColumnIndex<MySqlStatement> for usize
impl ColumnIndex<MySqlStatement> for usize
Sourcefn index(&self, statement: &MySqlStatement) -> Result<usize, Error>
fn index(&self, statement: &MySqlStatement) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.Sourceimpl Debug for MySqlStatement
impl Debug for MySqlStatement
Sourceimpl Statement for MySqlStatement
impl Statement for MySqlStatement
type Database = MySql
Sourcefn parameters(&self) -> Option<Either<&[MySqlTypeInfo], usize>>
fn parameters(&self) -> Option<Either<&[MySqlTypeInfo], usize>>
Get the expected parameters for this statement. Read more
Sourcefn columns(&self) -> &[MySqlColumn]
fn columns(&self) -> &[MySqlColumn]
Get the columns expected to be returned by executing this statement.
fn query( &self, ) -> Query<'_, <MySqlStatement as Statement>::Database, MySqlArguments>
fn query_with<A>( &self, arguments: A, ) -> Query<'_, <MySqlStatement as Statement>::Database, A>
fn query_as<O>( &self, ) -> QueryAs<'_, <MySqlStatement as Statement>::Database, O, <<MySqlStatement as Statement>::Database as Database>::Arguments>
fn query_as_with<'s, O, A>(
&'s self,
arguments: A,
) -> QueryAs<'s, <MySqlStatement as Statement>::Database, O, A>where
O: for<'r> FromRow<'r, <<MySqlStatement as Statement>::Database as Database>::Row>,
A: IntoArguments<<MySqlStatement as Statement>::Database>,
fn query_scalar<O>( &self, ) -> QueryScalar<'_, <MySqlStatement as Statement>::Database, O, <<MySqlStatement as Statement>::Database as Database>::Arguments>
fn query_scalar_with<'s, O, A>(
&'s self,
arguments: A,
) -> QueryScalar<'s, <MySqlStatement as Statement>::Database, O, A>where
(O,): for<'r> FromRow<'r, <<MySqlStatement as Statement>::Database as Database>::Row>,
A: IntoArguments<<MySqlStatement as Statement>::Database>,
Sourcefn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
Gets the column information at
index. Read moreSourcefn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
fn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
Gets the column information at
index or a ColumnIndexOutOfBounds error if out of bounds.Auto Trait Implementations
impl Freeze for MySqlStatement
impl RefUnwindSafe for MySqlStatement
impl Send for MySqlStatement
impl Sync for MySqlStatement
impl Unpin for MySqlStatement
impl UnwindSafe for MySqlStatement