pub struct PgStatement { /* private fields */ }Available on crate feature
postgres only.Trait Implementations
Sourceimpl Clone for PgStatement
impl Clone for PgStatement
Sourcefn clone(&self) -> PgStatement
fn clone(&self) -> PgStatement
Returns a duplicate of the value. Read more
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ColumnIndex<PgStatement> for &str
impl ColumnIndex<PgStatement> for &str
Sourcefn index(&self, statement: &PgStatement) -> Result<usize, Error>
fn index(&self, statement: &PgStatement) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.Sourceimpl ColumnIndex<PgStatement> for usize
impl ColumnIndex<PgStatement> for usize
Sourcefn index(&self, statement: &PgStatement) -> Result<usize, Error>
fn index(&self, statement: &PgStatement) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.Sourceimpl Debug for PgStatement
impl Debug for PgStatement
Sourceimpl Statement for PgStatement
impl Statement for PgStatement
type Database = Postgres
Sourcefn parameters(&self) -> Option<Either<&[PgTypeInfo], usize>>
fn parameters(&self) -> Option<Either<&[PgTypeInfo], usize>>
Get the expected parameters for this statement. Read more
Sourcefn columns(&self) -> &[PgColumn]
fn columns(&self) -> &[PgColumn]
Get the columns expected to be returned by executing this statement.
fn query(&self) -> Query<'_, <PgStatement as Statement>::Database, PgArguments>
fn query_with<A>( &self, arguments: A, ) -> Query<'_, <PgStatement as Statement>::Database, A>
fn query_as<O>( &self, ) -> QueryAs<'_, <PgStatement as Statement>::Database, O, <<PgStatement as Statement>::Database as Database>::Arguments>
fn query_as_with<'s, O, A>(
&'s self,
arguments: A,
) -> QueryAs<'s, <PgStatement as Statement>::Database, O, A>where
O: for<'r> FromRow<'r, <<PgStatement as Statement>::Database as Database>::Row>,
A: IntoArguments<<PgStatement as Statement>::Database>,
fn query_scalar<O>( &self, ) -> QueryScalar<'_, <PgStatement as Statement>::Database, O, <<PgStatement as Statement>::Database as Database>::Arguments>
fn query_scalar_with<'s, O, A>(
&'s self,
arguments: A,
) -> QueryScalar<'s, <PgStatement as Statement>::Database, O, A>where
(O,): for<'r> FromRow<'r, <<PgStatement as Statement>::Database as Database>::Row>,
A: IntoArguments<<PgStatement as Statement>::Database>,
Sourcefn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
Gets the column information at
index. Read moreSourcefn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
fn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
Gets the column information at
index or a ColumnIndexOutOfBounds error if out of bounds.Auto Trait Implementations
impl Freeze for PgStatement
impl RefUnwindSafe for PgStatement
impl Send for PgStatement
impl Sync for PgStatement
impl Unpin for PgStatement
impl UnwindSafe for PgStatement