pub struct PgPoint {
pub x: f64,
pub y: f64,
}Available on crate feature
postgres only.Expand description
Postgres Geometric Point type
Description: Point on a plane
Representation: (x, y)
Points are the fundamental two-dimensional building block for geometric types. Values of type point are specified using either of the following syntaxes:
( x , y )
x , ywhere x and y are the respective coordinates, as floating-point numbers.
See Postgres Manual, Section 8.8.1, Geometric Types - Points for details.
Fields
x: f64y: f64Trait Implementations
Sourceimpl Encode<'_, Postgres> for PgPoint
impl Encode<'_, Postgres> for PgPoint
fn produces(&self) -> Option<PgTypeInfo>
Sourcefn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Send + Sync>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Send + Sync>>
Sourcefn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Send + Sync>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Send + Sync>>where
Self: Sized,
Writes the value of
self into buf in the expected format for the database.fn size_hint(&self) -> usize
Sourceimpl PgHasArrayType for PgPoint
impl PgHasArrayType for PgPoint
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
impl StructuralPartialEq for PgPoint