Struct sqlx::query::QueryAs [−][src]
pub struct QueryAs<'q, DB, O, A> where
DB: Database, { /* fields omitted */ }Expand description
Raw SQL query with bind parameters, mapped to a concrete type using FromRow.
Returned from [query_as].
Implementations
Bind a value for use with this SQL query.
See Query::bind.
Execute the query and return the generated results as a stream.
Execute multiple queries and return the generated results as a stream from each query, in a stream.
Execute the query and return all the generated results, collected into a Vec.
Execute the query and returns exactly one row.