SqliteValueRef

Struct SqliteValueRef 

pub struct SqliteValueRef<'r>(/* private fields */);
Available on crate feature _sqlite only.
A borrowed reference to a sqlite3_value.

Semantically, this behaves as a reference to SqliteValue.

Note: Decoding is Stateful

See SqliteValue for details.

Implementations

Source

impl<'r> SqliteValueRef<'r>

pub fn try_to_owned(&self) -> Result<SqliteValue, SqliteError>

Attempt to duplicate the internal sqlite3_value with sqlite3_value_dup().

Returns an error if the call returns a null pointer, indicating that SQLite was unable to allocate the additional memory required.

Non-panicking version of Self::try_to_owned().