pub struct AnyConnection { /* private fields */ }Expand description
SEE DOCUMENTATION BEFORE USE. Runtime-generic database connection.
The underlying database drivers are chosen at runtime from the list set via
install_drivers. Any use of AnyConnection or AnyPool
without this will panic.
It is recommended to use install_default_drivers to activate all currently compiled-in drivers.
A connection to any SQLx database.
The database driver used is determined by the scheme of the connection url.
postgres://postgres@localhost/test
sqlite://a.sqliteImplementations
Sourceimpl AnyConnection
impl AnyConnection
Sourcepub fn backend_name(&self) -> &str
Available on crate feature any only.
pub fn backend_name(&self) -> &str
any only.Returns the name of the database backend in use (e.g. PostgreSQL, MySQL, SQLite, etc.)