[][src]Trait sqlx::Cursor

pub trait Cursor<'c, 'q>: Send {
    type Database: Database;
    fn next(
        &'cur mut self
    ) -> Pin<Box<dyn Future<Output = Result<Option<<Self::Database as HasRow<'cur>>::Row>, Error>> + 'cur + Send>>; }

Represents a result set, which is generated by executing a query against the database.

A Cursor can be created by either Executor::execute or Query::fetch.

Initially the Cursor is positioned before the first row. The next method moves the cursor to the next row, and because it returns None when there are no more rows, it can be used in a while loop to iterate through all returned rows.

Associated Types

Loading content...

Required methods

fn next(
    &'cur mut self
) -> Pin<Box<dyn Future<Output = Result<Option<<Self::Database as HasRow<'cur>>::Row>, Error>> + 'cur + Send>>

Fetch the next row in the result. Returns None if there are no more rows.

Loading content...

Implementors

impl<'c, 'q> Cursor<'c, 'q> for MySqlCursor<'c, 'q>[src]

type Database = MySql

impl<'c, 'q> Cursor<'c, 'q> for PgCursor<'c, 'q>[src]

type Database = Postgres

Loading content...