Module types

Module types 

Conversions between Rust and SQL types.

To see how each SQL type maps to a Rust type, see the corresponding types module for each database:

Any external types that have had Type implemented for, are re-exported in this module for convenience as downstream users need to use a compatible version of the external crate to take advantage of the implementation.

Re-exports

pub use types::uuid;
pub use types::Uuid;
pub use types::BitVec;
pub use types::BigDecimal;
pub use types::Decimal;

Modules

bstrbstr
chronochrono
ipnetipnet
ipnetworkipnetwork
mac_addressmac_address
timetime

Structs

BStr
A wrapper for &[u8] that provides convenient string oriented trait impls.
BString
A wrapper for Vec<u8> that provides convenient string oriented trait impls.
Json
Json for json and jsonb fields
JsonRawValue
Reference to a range of bytes encompassing a single valid JSON value in the input data.
Text
Map a SQL text value to/from a Rust type using Display and FromStr.

Enums

JsonValue
Represents any valid JSON value.

Traits

Type
Indicates that a SQL type is supported for a database.