pub struct SqliteConfig {
pub unsafe_load_extensions: Vec<String>,
}_unstable-docs only.Expand description
Configuration for the SQLite database driver.
Fields
unsafe_load_extensions: Vec<String>Specify extensions to load, either by name or by path.
Paths should be relative to the workspace root.
See Loading an Extension in the SQLite manual for details.
The sqlite-load-extension feature must be enabled and SQLite must be built
without SQLITE_OMIT_LOAD_EXTENSION enabled.
Note: Does Not Configure Runtime Extension Loading
Extensions to be loaded at runtime must be separately configured with
SqliteConnectOptions::extension() or SqliteConnectOptions::extension_with_entrypoint().
Safety
This causes arbitrary DLLs on the filesystem to be loaded at execution time, which can easily result in undefined behavior, memory corruption, or exploitable vulnerabilities if misused.
It is not possible to provide a truly safe version of this API.
Use this field with care, and only load extensions that you trust.
Example
Load the uuid and vsv extensions from sqlean.
sqlx.toml:
[common.drivers.sqlite]
unsafe-load-extensions = ["uuid", "vsv"]Trait Implementations
Sourceimpl Debug for SqliteConfig
impl Debug for SqliteConfig
Sourceimpl Default for SqliteConfig
impl Default for SqliteConfig
Sourcefn default() -> SqliteConfig
fn default() -> SqliteConfig