pub enum ConfigError {
Env(VarError),
NotFound {
path: PathBuf,
},
Io {
path: PathBuf,
error: Error,
},
Parse {
path: PathBuf,
error: Box<dyn Error + Send + Sync>,
},
ParseDisabled {
path: PathBuf,
},
}_unstable-docs only.Expand description
Error returned from various methods of Config.
Variants
Env(VarError)
The loading method expected CARGO_MANIFEST_DIR to be set and it wasnโt.
This is necessary to locate the root of the crate currently being compiled.
See the โEnvironment Variablesโ page of the Cargo Book for details.
NotFound
No configuration file was found. Not necessarily fatal.
Io
An I/O error occurred while attempting to read the config file at path.
If the error is io::ErrorKind::NotFound, Self::NotFound is returned instead.
Parse
An error in the TOML was encountered while parsing the config file at path.
The error gives line numbers and context when printed with Display/ToString.
Only returned if the sqlx-toml feature is enabled.
ParseDisabled
A sqlx.toml file was found or specified, but the sqlx-toml feature is not enabled.
Implementations
Sourceimpl ConfigError
impl ConfigError
Sourcepub fn from_io(path: impl Into<PathBuf>, error: Error) -> ConfigError
pub fn from_io(path: impl Into<PathBuf>, error: Error) -> ConfigError
Create a ConfigError from a std::io::Error.
Maps to either NotFound or Io.
Sourcepub fn not_found_path(&self) -> Option<&Path>
pub fn not_found_path(&self) -> Option<&Path>
If this error means the file was not found, return the path that was attempted.