SEE DOCUMENTATION BEFORE USE. Runtime-generic database driver.
The underlying database drivers are chosen at runtime from the list set via
install_drivers. Any use of [AnyConnection] or [AnyPool]
without this will panic.
It is recommended to use install_default_drivers to activate all currently compiled-in drivers.
Structs
- Opaque database driver. Capable of being used in place of any SQLx database driver. The actual driver used will be selected at runtime, from the connection url.
- Opaque options for connecting to a database. These may only be constructed by parsing from a connection url.
Enums
Traits
- An alias for
Executor<'_, Database = Any>.
Functions
- Install all currently compiled-in drivers for [
AnyConnection] to use. - Install the list of drivers for
AnyConnectionto use.