[−][src]Trait sqlx::database::HasStatement
Associate Database with a Statement of a generic lifetime.
The upcoming Rust feature, Generic Associated Types, should obviate the need for this trait.
Associated Types
type Database: Database[src]
type Statement: Statement<'q>[src]
The concrete Statement implementation for this database.