Encode

Trait Encode 

pub trait Encode<'q, DB>
where DB: Database,
{ // Required method fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>; // Provided methods fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>> where Self: Sized { ... } fn produces(&self) -> Option<<DB as Database>::TypeInfo> { ... } fn size_hint(&self) -> usize { ... } }
Encode a single value to be sent to the database.

Required Methods

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Writes the value of self into buf without moving self.

Where possible, make use of encode instead as it can take advantage of re-using memory.

Provided Methods

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where Self: Sized,

Writes the value of self into buf in the expected format for the database.

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

fn size_hint(&self) -> usize

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Encode<'_, Any> for String

Source

fn encode( self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, Any> for Vec<u8>

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, Any> for bool

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, Any> for f32

Source

impl Encode<'_, Any> for f64

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, Any> for i16

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, Any> for i32

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, Any> for i64

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for &[u8]

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for &str

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for BigDecimal

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for Date

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn size_hint(&self) -> usize

Source

impl Encode<'_, MySql> for DateTime<Local>

Note: assumes the connectionโ€™s time_zone is set to +00:00 (UTC).

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for DateTime<Utc>

Note: assumes the connectionโ€™s time_zone is set to +00:00 (UTC).

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for Decimal

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for Hyphenated

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for IpAddr

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for Ipv4Addr

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for Ipv6Addr

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for NaiveDate

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn size_hint(&self) -> usize

Source

impl Encode<'_, MySql> for NaiveDateTime

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn size_hint(&self) -> usize

Source

impl Encode<'_, MySql> for NaiveTime

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn size_hint(&self) -> usize

Source

impl Encode<'_, MySql> for OffsetDateTime

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for PrimitiveDateTime

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn size_hint(&self) -> usize

Source

impl Encode<'_, MySql> for Simple

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for Time

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn size_hint(&self) -> usize

Source

impl Encode<'_, MySql> for Uuid

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for Vec<u8>

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for bool

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for f32

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for f64

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for i8

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for i16

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for i32

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for i64

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for u8

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for u16

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for u32

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, MySql> for u64

Source

fn encode_by_ref( &self, buf: &mut Vec<u8>, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, Postgres> for &[u8]

Source

impl Encode<'_, Postgres> for &str

Source

impl Encode<'_, Postgres> for BigDecimal

Note: BigDecimal Has a Larger Range than NUMERIC

BigDecimal can represent values with a far, far greater range than the NUMERIC type in Postgres can.

NUMERIC is limited to 131,072 digits before the decimal point, and 16,384 digits after it. See Section 8.1, Numeric Types of the Postgres manual for details.

Meanwhile, BigDecimal can theoretically represent a value with an arbitrary number of decimal digits, albeit with a maximum of 263 significant figures.

Because encoding in the current API design must be infallible, when attempting to encode a BigDecimal that cannot fit in the wire representation of NUMERIC, SQLx may instead encode a sentinel value that falls outside the allowed range but is still representable.

This will cause the query to return a DatabaseError with code 22P03 (invalid_binary_representation) and the error message invalid scale in external "numeric" value (though this may be subject to change).

However, BigDecimal should be able to decode any NUMERIC value except NaN, for which it has no representation.

Source

impl Encode<'_, Postgres> for BitVec

Source

impl Encode<'_, Postgres> for Date

Source

impl Encode<'_, Postgres> for Decimal

Source

impl Encode<'_, Postgres> for Duration

Source

impl Encode<'_, Postgres> for Duration

Available on crate feature time only.
Source

impl Encode<'_, Postgres> for IpNet

Source

impl Encode<'_, Postgres> for IpNetwork

Source

impl Encode<'_, Postgres> for MacAddress

Source

impl Encode<'_, Postgres> for NaiveDate

Source

impl Encode<'_, Postgres> for NaiveDateTime

Source

impl Encode<'_, Postgres> for NaiveTime

Source

impl Encode<'_, Postgres> for OffsetDateTime

Source

impl Encode<'_, Postgres> for PrimitiveDateTime

Source

impl Encode<'_, Postgres> for Time

Source

impl Encode<'_, Postgres> for TimeDelta

Available on crate feature chrono only.
Source

impl Encode<'_, Postgres> for Uuid

Source

impl Encode<'_, Postgres> for Vec<u8>

Source

impl Encode<'_, Postgres> for bool

Source

impl Encode<'_, Postgres> for f32

Source

impl Encode<'_, Postgres> for f64

Source

impl Encode<'_, Postgres> for i8

Source

impl Encode<'_, Postgres> for i16

Source

impl Encode<'_, Postgres> for i32

Source

impl Encode<'_, Postgres> for i64

Source

impl Encode<'_, Sqlite> for &[u8]

Source

impl Encode<'_, Sqlite> for &str

Source

impl Encode<'_, Sqlite> for Arc<[u8]>

Source

impl Encode<'_, Sqlite> for Arc<str>

Source

fn encode( self, args: &mut <Sqlite as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where Arc<str>: Sized,

Source

fn encode_by_ref( &self, args: &mut SqliteArgumentsBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl Encode<'_, Sqlite> for Box<[u8]>

Source

impl Encode<'_, Sqlite> for Box<str>

Source

impl Encode<'_, Sqlite> for Cow<'_, [u8]>

Source

impl Encode<'_, Sqlite> for Cow<'_, str>

Source

impl Encode<'_, Sqlite> for Date

Source

impl Encode<'_, Sqlite> for Hyphenated

Source

impl Encode<'_, Sqlite> for NaiveDate

Source

impl Encode<'_, Sqlite> for NaiveDateTime

Source

impl Encode<'_, Sqlite> for NaiveTime

Source

impl Encode<'_, Sqlite> for OffsetDateTime

Source

impl Encode<'_, Sqlite> for PrimitiveDateTime

Source

impl Encode<'_, Sqlite> for Rc<[u8]>

Source

impl Encode<'_, Sqlite> for Rc<str>

Source

impl Encode<'_, Sqlite> for Simple

Source

impl Encode<'_, Sqlite> for String

Source

impl Encode<'_, Sqlite> for Time

Source

impl Encode<'_, Sqlite> for Uuid

Source

impl Encode<'_, Sqlite> for Vec<u8>

Source

impl Encode<'_, Sqlite> for bool

Source

impl Encode<'_, Sqlite> for f32

Source

impl Encode<'_, Sqlite> for f64

Source

impl Encode<'_, Sqlite> for i8

Source

impl Encode<'_, Sqlite> for i16

Source

impl Encode<'_, Sqlite> for i32

Source

impl Encode<'_, Sqlite> for i64

Source

impl Encode<'_, Sqlite> for u8

Source

impl Encode<'_, Sqlite> for u16

Source

impl Encode<'_, Sqlite> for u32

Source

impl<'a> Encode<'a, Any> for &'a str

Source

fn encode( self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where &'a str: Sized,

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'db> Encode<'db, Postgres> for IpAddr
where IpNetwork: Encode<'db, Postgres>,

Source

impl<'q, DB> Encode<'q, DB> for Box<RawValue>
where Json<&'a Box<RawValue>>: for<'a> Encode<'q, DB>, DB: Database,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<i8>
where DB: Database, i8: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<i8>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<i16>
where DB: Database, i16: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<i16>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<i32>
where DB: Database, i32: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<i32>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<i64>
where DB: Database, i64: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<i64>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<u8>
where DB: Database, u8: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<u8>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<u16>
where DB: Database, u16: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<u16>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<u32>
where DB: Database, u32: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<u32>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, DB> Encode<'q, DB> for NonZero<u64>
where DB: Database, u64: Encode<'q, DB>,

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
where NonZero<u64>: Sized,

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

impl<'q, T, DB> Encode<'q, DB> for &T
where DB: Database, T: Encode<'q, DB>,

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

fn size_hint(&self) -> usize

Source

impl<'q, T, DB> Encode<'q, DB> for Arc<T>
where DB: Database, T: Encode<'q, DB>,

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

fn size_hint(&self) -> usize

Source

impl<'q, T, DB> Encode<'q, DB> for Box<T>
where DB: Database, T: Encode<'q, DB>,

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

fn size_hint(&self) -> usize

Source

impl<'q, T, DB> Encode<'q, DB> for Cow<'q, T>
where DB: Database, T: Encode<'q, DB> + ToOwned,

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

fn size_hint(&self) -> usize

Source

impl<'q, T, DB> Encode<'q, DB> for Rc<T>
where DB: Database, T: Encode<'q, DB>,

Source

fn encode( self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn encode_by_ref( &self, buf: &mut <DB as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

fn produces(&self) -> Option<<DB as Database>::TypeInfo>

Source

fn size_hint(&self) -> usize

Source

impl<'q, T, const N: usize> Encode<'q, Postgres> for [T; N]
where &'a [T]: for<'a> Encode<'q, Postgres>, T: Encode<'q, Postgres>,

Source

impl<'q, T> Encode<'q, Any> for Option<T>
where T: Encode<'q, Any> + 'q + Type<Any>,

Source

impl<'q, T> Encode<'q, MySql> for Option<T>
where T: Encode<'q, MySql> + Type<MySql> + 'q,

Source

impl<'q, T> Encode<'q, Postgres> for &[T]
where T: Encode<'q, Postgres> + Type<Postgres>,

Source

impl<'q, T> Encode<'q, Postgres> for Option<T>
where T: Encode<'q, Postgres> + Type<Postgres> + 'q,

Source

impl<'q, T> Encode<'q, Postgres> for Vec<T>
where &'a [T]: for<'a> Encode<'q, Postgres>, T: Encode<'q, Postgres>,

Source

impl<'q, T> Encode<'q, Sqlite> for Option<T>
where T: Encode<'q, Sqlite> + Type<Sqlite> + 'q,

Source

impl<'q> Encode<'q, Any> for &'q [u8]

Source

fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>

Source

impl<'q> Encode<'q, MySql> for Arc<[u8]>

Source

impl<'q> Encode<'q, MySql> for Arc<str>

Source

impl<'q> Encode<'q, MySql> for Box<[u8]>

Source

impl<'q> Encode<'q, MySql> for Box<str>

Source

impl<'q> Encode<'q, MySql> for Cow<'_, [u8]>

Source

impl<'q> Encode<'q, MySql> for Cow<'_, str>

Source

impl<'q> Encode<'q, MySql> for Rc<[u8]>

Source

impl<'q> Encode<'q, MySql> for Rc<str>

Source

impl<'q> Encode<'q, MySql> for String

Source

impl<'q> Encode<'q, Postgres> for Arc<[u8]>

Source

impl<'q> Encode<'q, Postgres> for Arc<str>

Source

impl<'q> Encode<'q, Postgres> for Box<[u8]>

Source

impl<'q> Encode<'q, Postgres> for Box<str>

Source

impl<'q> Encode<'q, Postgres> for Cow<'_, [u8]>

Source

impl<'q> Encode<'q, Postgres> for Cow<'_, str>

Source

impl<'q> Encode<'q, Postgres> for Rc<[u8]>

Source

impl<'q> Encode<'q, Postgres> for Rc<str>

Source

impl<'q> Encode<'q, Postgres> for String

Source

impl<Tz> Encode<'_, Postgres> for DateTime<Tz>
where Tz: TimeZone,

Source

impl<Tz> Encode<'_, Sqlite> for DateTime<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Display,

Source

impl<const N: usize> Encode<'_, Postgres> for [u8; N]

Implementors

Source

impl Encode<'_, MySql> for MySqlTime

Source

impl Encode<'_, Postgres> for Oid

Source

impl Encode<'_, Postgres> for PgBox

Source

impl Encode<'_, Postgres> for PgCiText

Source

impl Encode<'_, Postgres> for PgCircle

Source

impl Encode<'_, Postgres> for PgCube

Source

impl Encode<'_, Postgres> for PgHstore

Source

impl Encode<'_, Postgres> for PgInterval

Source

impl Encode<'_, Postgres> for PgLQuery

Source

impl Encode<'_, Postgres> for PgLSeg

Source

impl Encode<'_, Postgres> for PgLTree

Source

impl Encode<'_, Postgres> for PgLine

Source

impl Encode<'_, Postgres> for PgMoney

Source

impl Encode<'_, Postgres> for PgPath

Source

impl Encode<'_, Postgres> for PgPoint

Source

impl Encode<'_, Postgres> for PgPolygon

Source

impl Encode<'_, Postgres> for PgTimeTz

Source

impl Encode<'_, Postgres> for PgTimeTz<NaiveTime, FixedOffset>

Source

impl<'q, DB> Encode<'q, DB> for &'q BStr
where DB: Database, &'q [u8]: Encode<'q, DB>,

Source

impl<'q, DB> Encode<'q, DB> for &'q RawValue
where Json<&'a &'q RawValue>: for<'a> Encode<'q, DB>, DB: Database,

Source

impl<'q, DB> Encode<'q, DB> for BString
where DB: Database, Vec<u8>: Encode<'q, DB>,

Source

impl<'q, DB> Encode<'q, DB> for RawValue
where Json<&'a RawValue>: for<'a> Encode<'q, DB>, DB: Database,

Source

impl<'q, DB> Encode<'q, DB> for Value
where Json<&'a Value>: for<'a> Encode<'q, DB>, DB: Database,

Source

impl<'q, T> Encode<'q, Postgres> for PgRange<T>
where T: Encode<'q, Postgres>,

Source

impl<T> Encode<'_, MySql> for Json<T>
where T: Serialize,

Source

impl<T> Encode<'_, MySql> for Text<T>
where T: Display,

Source

impl<T> Encode<'_, Postgres> for Json<T>
where T: Serialize,

Source

impl<T> Encode<'_, Postgres> for Text<T>
where T: Display,

Source

impl<T> Encode<'_, Sqlite> for Json<T>
where T: Serialize,

Source

impl<T> Encode<'_, Sqlite> for Text<T>
where T: Display,