Trait sqlx::error::DatabaseError [−][src]
An error that was returned from the database.
Required methods
Loading content...Provided methods
pub fn code(&self) -> Option<Cow<'_, str>>[src]
The (SQLSTATE) code for the error.
pub fn constraint(&self) -> Option<&str>[src]
Returns the name of the constraint that triggered the error, if applicable. If the error was caused by a conflict of a unique index, this will be the index name.
Note
Currently only populated by the Postgres driver.
Implementations
impl dyn DatabaseError + 'static[src]
pub fn downcast_ref<E>(&self) -> &E where
E: DatabaseError, [src]
E: DatabaseError,
Downcast a reference to this generic database error to a specific database error type.
Panics
Panics if the database error type is not E. This is a deliberate contrast from
Error::downcast_ref which returns Option<&E>. In normal usage, you should know the
specific error type. In other cases, use try_downcast_ref.
pub fn downcast<E>(
self: Box<dyn DatabaseError + 'static, Global>
) -> Box<E, Global> where
E: DatabaseError, [src]
self: Box<dyn DatabaseError + 'static, Global>
) -> Box<E, Global> where
E: DatabaseError,
Downcast this generic database error to a specific database error type.
Panics
Panics if the database error type is not E. This is a deliberate contrast from
Error::downcast which returns Option<E>. In normal usage, you should know the
specific error type. In other cases, use try_downcast.
pub fn try_downcast_ref<E>(&self) -> Option<&E> where
E: DatabaseError, [src]
E: DatabaseError,
Downcast a reference to this generic database error to a specific database error type.
pub fn try_downcast<E>(
self: Box<dyn DatabaseError + 'static, Global>
) -> Result<Box<E, Global>, Box<dyn DatabaseError + 'static, Global>> where
E: DatabaseError, [src]
self: Box<dyn DatabaseError + 'static, Global>
) -> Result<Box<E, Global>, Box<dyn DatabaseError + 'static, Global>> where
E: DatabaseError,
Downcast this generic database error to a specific database error type.