pub struct ResolveConfig { /* private fields */ }migrate only.Expand description
Configuration for migration resolution using ResolveWith.
Implementations
Sourceimpl ResolveConfig
impl ResolveConfig
Sourcepub fn new() -> ResolveConfig
pub fn new() -> ResolveConfig
Return a default, empty configuration.
Sourcepub fn ignore_char(&mut self, c: char) -> &mut ResolveConfig
pub fn ignore_char(&mut self, c: char) -> &mut ResolveConfig
Ignore a character when hashing migrations.
The migration SQL string itself will still contain the character, but it will not be included when calculating the checksum.
This can be used to ignore whitespace characters so changing formatting does not change the checksum.
Adding the same char more than once is a no-op.
Note: Changes Migration Checksum
This will change the checksum of resolved migrations, which may cause problems with existing deployments.
Use at your own risk.
Sourcepub fn ignore_chars(
&mut self,
chars: impl IntoIterator<Item = char>,
) -> &mut ResolveConfig
pub fn ignore_chars( &mut self, chars: impl IntoIterator<Item = char>, ) -> &mut ResolveConfig
Ignore one or more characters when hashing migrations.
The migration SQL string itself will still contain these characters, but they will not be included when calculating the checksum.
This can be used to ignore whitespace characters so changing formatting does not change the checksum.
Adding the same char more than once is a no-op.
Note: Changes Migration Checksum
This will change the checksum of resolved migrations, which may cause problems with existing deployments.
Use at your own risk.
Sourcepub fn ignored_chars(&self) -> impl Iterator<Item = char>
pub fn ignored_chars(&self) -> impl Iterator<Item = char>
Iterate over the set of ignored characters.
Duplicate chars are not included.