[−][src]Module sqlx::query
Types and traits for the query family of functions and macros.
Structs
| Map | SQL query that will map its results to owned Rust types. |
| Query | Raw SQL query with bind parameters. Returned by |
| QueryAs | Raw SQL query with bind parameters, mapped to a concrete type using |
| QueryScalar | Raw SQL query with bind parameters, mapped to a concrete type using |
Traits
| MapRow | |
| TryMapRow |