pub struct AssertSqlSafe<T>(pub T);Expand description
Assert that a query string is safe to execute on a database connection.
Using this API means that you have made sure that the string contents do not contain a SQL injection vulnerability. It means that, if the string was constructed dynamically, and/or from user input, you have taken care to sanitize the input yourself. SQLx does not provide any sort of sanitization; the design of SQLx prefers the use of prepared statements for dynamic input.
The maintainers of SQLx take no responsibility for any data leaks or loss resulting from misuse of this API. Use at your own risk.
Note that &'static str implements SqlSafeStr directly and so does not need to be wrapped
with this type.
Tuple Fields
0: TTrait Implementations
Sourceimpl SqlSafeStr for AssertSqlSafe<&str>
Note: copies the string.
impl SqlSafeStr for AssertSqlSafe<&str>
Note: copies the string.
It is recommended to pass one of the supported owned string types instead.
Sourcefn into_sql_str(self) -> SqlStr
fn into_sql_str(self) -> SqlStr
self to a SqlStr.Sourceimpl SqlSafeStr for AssertSqlSafe<Arc<String>>
impl SqlSafeStr for AssertSqlSafe<Arc<String>>
Sourcefn into_sql_str(self) -> SqlStr
fn into_sql_str(self) -> SqlStr
self to a SqlStr.Sourceimpl SqlSafeStr for AssertSqlSafe<Arc<str>>
impl SqlSafeStr for AssertSqlSafe<Arc<str>>
Sourcefn into_sql_str(self) -> SqlStr
fn into_sql_str(self) -> SqlStr
self to a SqlStr.Sourceimpl SqlSafeStr for AssertSqlSafe<Box<str>>
impl SqlSafeStr for AssertSqlSafe<Box<str>>
Sourcefn into_sql_str(self) -> SqlStr
fn into_sql_str(self) -> SqlStr
self to a SqlStr.Sourceimpl SqlSafeStr for AssertSqlSafe<Cow<'static, str>>
impl SqlSafeStr for AssertSqlSafe<Cow<'static, str>>
Sourcefn into_sql_str(self) -> SqlStr
fn into_sql_str(self) -> SqlStr
self to a SqlStr.Sourceimpl SqlSafeStr for AssertSqlSafe<String>
impl SqlSafeStr for AssertSqlSafe<String>
Sourcefn into_sql_str(self) -> SqlStr
fn into_sql_str(self) -> SqlStr
self to a SqlStr.Auto Trait Implementations
impl<T> Freeze for AssertSqlSafe<T>where
T: Freeze,
impl<T> RefUnwindSafe for AssertSqlSafe<T>where
T: RefUnwindSafe,
impl<T> Send for AssertSqlSafe<T>where
T: Send,
impl<T> Sync for AssertSqlSafe<T>where
T: Sync,
impl<T> Unpin for AssertSqlSafe<T>where
T: Unpin,
impl<T> UnwindSafe for AssertSqlSafe<T>where
T: UnwindSafe,