ColumnIndex

Trait ColumnIndex 

pub trait ColumnIndex<T>: Debug
where T: ?Sized,
{ // Required method fn index(&self, container: &T) -> Result<usize, Error>; }
A type that can be used to index into a Row or Statement.

The get and try_get methods of Row accept any type that implements ColumnIndex. This trait is implemented for strings which are used to look up a column by name, and for usize which is used as a positional index into the row.

Required Methods

fn index(&self, container: &T) -> Result<usize, Error>

Returns a valid positional index into the row or statement, ColumnIndexOutOfBounds, or, ColumnNotFound.

Implementations on Foreign Types

Source

impl ColumnIndex<AnyRow> for &str

Source

fn index(&self, row: &AnyRow) -> Result<usize, Error>

Source

impl ColumnIndex<AnyRow> for usize

Source

fn index(&self, row: &AnyRow) -> Result<usize, Error>

Source

impl ColumnIndex<AnyStatement> for &str

Source

fn index(&self, statement: &AnyStatement) -> Result<usize, Error>

Source

impl ColumnIndex<AnyStatement> for usize

Source

fn index(&self, statement: &AnyStatement) -> Result<usize, Error>

Source

impl ColumnIndex<MySqlRow> for &str

Source

impl ColumnIndex<MySqlRow> for usize

Source

impl ColumnIndex<MySqlStatement> for &str

Source

fn index(&self, statement: &MySqlStatement) -> Result<usize, Error>

Source

impl ColumnIndex<MySqlStatement> for usize

Source

fn index(&self, statement: &MySqlStatement) -> Result<usize, Error>

Source

impl ColumnIndex<PgRow> for &str

Source

fn index(&self, row: &PgRow) -> Result<usize, Error>

Source

impl ColumnIndex<PgRow> for usize

Source

fn index(&self, row: &PgRow) -> Result<usize, Error>

Source

impl ColumnIndex<PgStatement> for &str

Source

fn index(&self, statement: &PgStatement) -> Result<usize, Error>

Source

impl ColumnIndex<PgStatement> for usize

Source

fn index(&self, statement: &PgStatement) -> Result<usize, Error>

Source

impl ColumnIndex<SqliteRow> for &str

Source

impl ColumnIndex<SqliteRow> for usize

Source

impl ColumnIndex<SqliteStatement> for &str

Source

fn index(&self, statement: &SqliteStatement) -> Result<usize, Error>

Source

impl ColumnIndex<SqliteStatement> for usize

Source

fn index(&self, statement: &SqliteStatement) -> Result<usize, Error>

Source

impl<T, I> ColumnIndex<T> for &I
where I: ColumnIndex<T> + ?Sized, T: ?Sized,

Source

fn index(&self, row: &T) -> Result<usize, Error>

Implementors