[−][src]Module sqlx::types
Conversions between Rust and SQL types.
To see how each SQL type maps to a Rust type, see the corresponding types module for each
database:
Any external types that have had [Type] implemented for, are re-exported in this module
for convenience as downstream users need to use a compatible version of the external crate
to take advantage of the implementation.
Modules
| chrono | |
| ipnetwork | |
| time |
Structs
| BigDecimal | A big decimal type. |
| Json | |
| Uuid | A Universally Unique Identifier (UUID). |
Traits
| Type | Indicates that a SQL type is supported for a database. |
| TypeInfo |