[−][src]Module sqlx::types
Traits linking Rust types to SQL types.
Traits
| HasSqlType | Indicates that a SQL type is supported for a database. |
| HasTypeMetadata | Information about how a database stores metadata about given SQL types. |
Traits linking Rust types to SQL types.
| HasSqlType | Indicates that a SQL type is supported for a database. |
| HasTypeMetadata | Information about how a database stores metadata about given SQL types. |